"""
Django settings for django_postgresql project.

Generated by 'django-admin startproject' using Django 2.0.4.

For more information on this file, see
https://docs.djangoproject.com/en/2.0/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/2.0/ref/settings/
"""

import os
from lofar.common import dbcredentials
import logging


# logger
logger = logging.getLogger('django_settings')
logger.addHandler(logging.StreamHandler())
logger.setLevel(logging.DEBUG)

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/2.0/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'x)5=9*2a&)32h-loh@rlt_9eyw%t$-fqao*#1j2gh^7=^bnjyy'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

ALLOWED_HOSTS = ['lofarmonitortest.control.lofar', 'localhost', '127.0.0.1']


# Application definition

INSTALLED_APPS = [
    'django.contrib.admin',
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'rest_framework',
    'django_filters',
    'lofar.maintenance.monitoringdb.apps.MonitoringDbConfig',
]

MIDDLEWARE = [
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
]

ROOT_URLCONF = 'lofar.maintenance.django_postgresql.urls'

TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [],
        'APP_DIRS': True,
        'OPTIONS': {
            'context_processors': [
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
        },
    },
]

WSGI_APPLICATION = 'lofar.maintenance.django_postgresql.wsgi.application'

LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'formatters': {
        'verbose': {
            'format': '%(levelname)s %(asctime)s %(module)s proc:%(process)d thread:%(thread)d > %(message)s'
        },
        'simple': {
            'format': '%(levelname)s > %(message)s'
        },
    },
    'handlers': {
        'console': {
            'class': 'logging.StreamHandler',
            'formatter': 'verbose',
            'level': 'DEBUG'
        }
    },
    'loggers': {
        'station_test.parser': {
            'handlers': ['console'],
            'level': 'DEBUG',
        },
        'views': {
            'handlers': ['console'],
            'level': 'DEBUG',
        },
        'serializers': {
            'handlers': ['console'],
            'level': 'DEBUG',
        },
        'controllers': {
            'handlers': ['console'],
            'level': 'DEBUG'
        }
    },
}

# Database
# https://docs.djangoproject.com/en/2.0/ref/settings/#databases

# Read Postgres DB settings

# this requires a config file in ~/.lofar/dbcredentials/lsmr.ini
# if no such file exists then it is automatically created.
# It is also possible to set another credentials-name via the LSMR_DBCREDENTIALS env-var for testing for example.
#
# contents should be like this (adapt as needed):
#
# [database:mdb]
# type = postgresql
# host = localhost
# database = <your_lsmr_database_name>
# port = 5432
# user = <your_lsmr_user_name>
# password = <your_lsmr_password>

creds_name = os.environ.get('MDB_DBCREDENTIALS', 'mdb')
django_db_credentials = dbcredentials.DBCredentials().get(creds_name)

DATABASES = {
    'default': {
        # Postgres:
        'ENGINE': 'django.db.backends.postgresql_psycopg2',
        'NAME': django_db_credentials.database,
        'USER': django_db_credentials.user,
        'PASSWORD': django_db_credentials.password,
        'HOST': django_db_credentials.host,
        'PORT': django_db_credentials.port,
        }
}
# Password validation
# https://docs.djangoproject.com/en/2.0/ref/settings/#auth-password-validators
AUTH_PASSWORD_VALIDATORS = [
    {
        'NAME': 'django.contrib.auth.password_validation.UserAttributeSimilarityValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.MinimumLengthValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.CommonPasswordValidator',
    },
    {
        'NAME': 'django.contrib.auth.password_validation.NumericPasswordValidator',
    },
]


# Internationalization
# https://docs.djangoproject.com/en/2.0/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.0/howto/static-files/

STATIC_URL = '/static/'

REST_FRAMEWORK = {
    'DEFAULT_PAGINATION_CLASS': 'lofar.maintenance.monitoringdb.pagination.DefaultPaginationSettings',
    'STRICT_JSON': False,
    'DEFAULT_FILTER_BACKENDS': ('django_filters.rest_framework.DjangoFilterBackend',)
}

CELERY_RESULT_BACKEND = 'amqp://guest@localhost//'
# LOFAR SPECIFIC PARAMETERS
URL_TO_STORE_RTSM_PLOTS = '/data/deploy/production/rtsm_plots'